@@ -85,30 +85,12 @@ void *common_drm_get_pixmap_data(PixmapPtr pixmap)
 
 static uint64_t common_drm_frame_to_msc(xf86CrtcPtr crtc, uint32_t seq)
 {
-	struct common_crtc_info *drmc = common_crtc(crtc);
-
-	/*
-	 * The sequence counter wrapped.  Unlike the misleading comments in
-	 * xf86-video-intel, the vblank counter is never wound backwards: it
-	 * always runs forwards.  However, since we don't monitor it with
-	 * any regularity, it can appear to go backwards if we wait (eg)
-	 * 0xc0000000 vblanks between calls.  Hence, whenever we see the
-	 * frame sequence less than the last sequence, assume that it has
-	 * wrapped.  (It may have wrapped more than once.)
-	 */
-	if (seq < drmc->last_seq)
-		drmc->last_msc += 0x100000000ULL;
-
-	drmc->last_seq = seq;
-
-	return drmc->last_msc + seq;
+	return seq;
 }
 
 static uint32_t common_drm_msc_to_frame(xf86CrtcPtr crtc, uint64_t msc)
 {
-	struct common_crtc_info *drmc = common_crtc(crtc);
-
-	return msc - drmc->last_msc;
+	return (uint32_t) msc;
 }
 
 /*
@@ -1067,13 +1049,7 @@ xf86CrtcPtr common_drm_drawable_covering_crtc(DrawablePtr pDraw)
 
 	box_init(&box, pDraw->x, pDraw->y, pDraw->width, pDraw->height);
 
-	crtc = common_drm_covering_crtc(pScrn, &box, NULL, &crtcbox);
-
-	/* Make sure the CRTC is valid and this is the real front buffer */
-	if (crtc && crtc->rotatedData)
-		crtc = NULL;
-
-	return crtc;
+	return common_drm_covering_crtc(pScrn, &box, NULL, &crtcbox);
 }
 
 static inline uint32_t req_crtc(xf86CrtcPtr crtc)
